import { __assign, __spreadArray } from './../external/tslib/tslib.es6.js';
import React, { useMemo } from 'react';
import classnames from 'classnames';
import noop from 'lodash/noop';
import uniqueId from 'lodash/uniqueId';
import { parseMetadata } from '@highlight-ui/utils-commons';
import Checkbox from './Checkbox.js';
import styles from './CheckboxGroup.module.scss.js';

var valuesToOptions = function (values, options) {
  return options.filter(function (option) {
    return values === null || values === void 0 ? void 0 : values.includes(option.value);
  });
}; // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types


var CheckboxGroupWithRef = function (_a, ref) {
  var _b;

  var className = _a.className,
      metadata = _a.metadata,
      name = _a.name,
      _c = _a.disabled,
      disabled = _c === void 0 ? false : _c,
      _d = _a.orientation,
      orientation = _d === void 0 ? 'vertical' : _d,
      options = _a.options,
      _e = _a.value,
      value = _e === void 0 ? [] : _e,
      _f = _a.onChange,
      onChange = _f === void 0 ? noop : _f;
  var generatedName = useMemo(function () {
    return uniqueId('CheckboxGroupOption-');
  }, []);
  var checkboxGroupName = name || generatedName;
  var selectedOptions = valuesToOptions(value, options);
  return /*#__PURE__*/React.createElement("div", __assign({
    ref: ref,
    className: classnames(className, styles.checkboxGroup, (_b = {}, _b[styles.checkboxGroupHorizontal] = orientation === 'horizontal', _b))
  }, parseMetadata(metadata)), options.map(function (option) {
    return /*#__PURE__*/React.createElement(Checkbox, {
      key: option.value + "-" + checkboxGroupName,
      metadata: option.metadata,
      className: classnames(option.className, styles.checkboxGroupOption),
      id: option.id,
      label: option.label,
      subLabel: option.subLabel,
      value: option.value,
      disabled: disabled || option.disabled,
      checked: value.includes(option.value),
      name: checkboxGroupName,
      onChange: function (e) {
        var isChecked = e.currentTarget.checked;
        var newOptions = isChecked ? __spreadArray(__spreadArray([], selectedOptions, true), [option], false) : selectedOptions.filter(function (v) {
          return v.value !== option.value;
        });
        onChange(newOptions);
      }
    });
  }));
};

CheckboxGroupWithRef.displayName = 'CheckboxGroup';
var CheckboxGroup = /*#__PURE__*/React.forwardRef(CheckboxGroupWithRef);
export { CheckboxGroup as default };
//# sourceMappingURL=CheckboxGroup.js.map
